
library(MASS)
source("anadisc.R")
source("mvdnorm.R")
source("lcur.ad.R")

# ------- ------- ------- 
# Donnees 
Donn <- read.table("Donn.txt", header=F)

N <- dim(Donn)[1]
pa <- 2/3
Na <- round(N*pa)

ind <- sample(1:N)
inda <- ind[1:Na]
indt <- ind[-(1:Na)]

Xapp <- as.matrix(Donn[inda,1:2])
zapp <- Donn[inda,3]

Xtst <- as.matrix(Donn[indt,1:2])
ztst <- Donn[indt,3]


# ------- ------- ------- 

# 1. ADL 
model.adl <- adl.app(Xapp, zapp)

# 2. ADQ 
model.adq <- adq.app(Xapp, zapp)

# 3. Naive Bayes 
model.nba <- nba.app(Xapp, zapp)

if (dim(Xtst)[1]>0)
{
	pred.adl <- ad.val(model.adl, Xtst)
	pred.adq <- ad.val(model.adq, Xtst)
	pred.nba <- ad.val(model.nba, Xtst)
}


# ------- ------- ------- 
# Affichage des sorties 

quartz()
lcur.ad(model.adq, Xapp, zapp, seq(from=0.1, to=0.9, by=0.1))

quartz()
lcur.ad(model.adl, Xapp, zapp, seq(from=0.1, to=0.9, by=0.1))

quartz()
lcur.ad(model.nba, Xapp, zapp, seq(from=0.1, to=0.9, by=0.1))


# ------- ------- ------- 
# Taux d'erreur moyen 

tauxerr <- NULL
tauxerr$ADL <- rep(-1,T)
tauxerr$ADQ <- rep(-1,T)
tauxerr$NBA <- rep(-1,T)

nbTr <- 50

for (t in 1:nbTr)
{
	ind <- sample(1:N)
	inda <- ind[1:Na]
	indt <- ind[-(1:Na)]

	Xapp <- as.matrix(Donn[inda,1:2])
	zapp <- Donn[inda,3]

	Xtst <- as.matrix(Donn[indt,1:2])
	ztst <- Donn[indt,3]

	model.adl <- adl.app(Xapp, zapp)
	model.adq <- adq.app(Xapp, zapp)
	model.nba <- nba.app(Xapp, zapp)

	pred.adl <- ad.val(model.adl, Xtst)
	pred.adq <- ad.val(model.adq, Xtst)
	pred.nba <- ad.val(model.nba, Xtst)

	tauxerr$ADL[t] <- mean(pred.adl$pred!=ztst)
	tauxerr$ADQ[t] <- mean(pred.adq$pred!=ztst)
	tauxerr$NBA[t] <- mean(pred.nba$pred!=ztst)
}

cat(sprintf("taux d'erreur ADL : %1.2f +/- %1.2f\n", mean(tauxerr$ADL), qt(.95,nbTr-1)*sd(tauxerr$ADL)/sqrt(nbTr)))
cat(sprintf("taux d'erreur ADQ : %1.2f +/- %1.2f\n", mean(tauxerr$ADQ), qt(.95,nbTr-1)*sd(tauxerr$ADQ)/sqrt(nbTr)))
cat(sprintf("taux d'erreur NBA : %1.2f +/- %1.2f\n", mean(tauxerr$NBA), qt(.95,nbTr-1)*sd(tauxerr$ADQ)/sqrt(nbTr)))

